# SWJFF (Some weird JSON-like file format)

Serialize your data to a file using the SWJFF format in python (currently).
The structure is similar to a JSON file.

## Installation
later

## Features [Full Version]:
- zstd compression support
- lmza compression support
- password encryption

## About
hi, this is stupid. Just use other packages that is much better than this.

## Additional Information
- [Specification](SPECIFICATION.md)